==> apache-tinkerpop-3.4.0-src.zip: tinkerpop-3.4.0/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/ser/binary/types/MonthDaySerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.driver.ser.binary.types;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufAllocator;
import org.apache.tinkerpop.gremlin.driver.ser.SerializationException;
import org.apache.tinkerpop.gremlin.driver.ser.binary.DataType;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryReader;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryWriter;

import java.time.MonthDay;

/**
 * @author Stephen Mallette (http://stephen.genoprime.com)
 */
public class MonthDaySerializer extends SimpleTypeSerializer<MonthDay> {
    public MonthDaySerializer() {
        super(DataType.MONTHDAY);
    }

    @Override
    MonthDay readValue(final ByteBuf buffer, final GraphBinaryReader context) throws SerializationException {
        return MonthDay.of(buffer.readByte(), buffer.readByte());
    }

    @Override
    public ByteBuf writeValue(final MonthDay value, final ByteBufAllocator allocator, final GraphBinaryWriter context) throws SerializationException {
        return allocator.buffer(2).writeByte(value.getMonthValue()).writeByte(value.getDayOfMonth());
    }
}

==> apache-tinkerpop-3.4.4-src.zip: tinkerpop-3.4.4/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/ser/binary/types/MonthDaySerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.driver.ser.binary.types;

import io.netty.buffer.ByteBuf;
import org.apache.tinkerpop.gremlin.driver.ser.SerializationException;
import org.apache.tinkerpop.gremlin.driver.ser.binary.DataType;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryReader;
import org.apache.tinkerpop.gremlin.driver.ser.binary.GraphBinaryWriter;

import java.time.MonthDay;

/**
 * @author Stephen Mallette (http://stephen.genoprime.com)
 */
public class MonthDaySerializer extends SimpleTypeSerializer<MonthDay> {
    public MonthDaySerializer() {
        super(DataType.MONTHDAY);
    }

    @Override
    protected MonthDay readValue(final ByteBuf buffer, final GraphBinaryReader context) throws SerializationException {
        return MonthDay.of(buffer.readByte(), buffer.readByte());
    }

    @Override
    protected void writeValue(final MonthDay value, final ByteBuf buffer, final GraphBinaryWriter context) throws SerializationException {
        buffer.writeByte(value.getMonthValue()).writeByte(value.getDayOfMonth());
    }
}
